#[non_exhaustive]pub enum PcmError {
UnsupportedSampleRate(u32),
EncodingMismatch,
}Expand description
A typed PCM-boundary refusal.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnsupportedSampleRate(u32)
The rate is zero or beyond the supported conversion bound.
EncodingMismatch
The format’s depth does not match the owned sample variant.