pub fn mix_excluding(
sources: &[Vec<i16>],
exclude: usize,
samples: usize,
) -> Vec<i16>Expand description
Mix everything in sources except the one at exclude.
This is the N-1 mix, done for one participant. exclude out of range mixes everything,
which is what a listener who is not a contributor wants.